pub struct GpuAdagrad { /* private fields */ }Expand description
GPU Adagrad with learning-rate decay.
Implementations
Sourceimpl GpuAdagrad
impl GpuAdagrad
Sourcepub fn new(params: AdagradParams) -> Result<Self, GpuOptimError>
pub fn new(params: AdagradParams) -> Result<Self, GpuOptimError>
Create the optimizer with the default WebGPU backend.
Sourcepub fn with_config(
params: AdagradParams,
config: GpuOptimizerConfig,
) -> Result<Self, GpuOptimError>
pub fn with_config( params: AdagradParams, config: GpuOptimizerConfig, ) -> Result<Self, GpuOptimError>
Create the optimizer on an explicit backend.
Sourcepub fn backend(&self) -> GpuBackend
pub fn backend(&self) -> GpuBackend
Backend actually in use.
Sourcepub fn move_to_gpu(&mut self) -> Result<(), GpuOptimError>
pub fn move_to_gpu(&mut self) -> Result<(), GpuOptimError>
Upload the optimizer state to device memory.
Inherent alias for GpuOptimizer::move_to_gpu so callers do not
need a turbofish to pin the unused dimension parameter.
Sourcepub fn move_to_cpu(&mut self) -> Result<(), GpuOptimError>
pub fn move_to_cpu(&mut self) -> Result<(), GpuOptimError>
Download the optimizer state back to host memory.
Inherent alias for GpuOptimizer::move_to_cpu; see
Self::move_to_gpu.
Sourcepub fn to_gpu(&mut self) -> Result<(), GpuOptimError>
👎Deprecated since 0.3.2: renamed to move_to_gpu
pub fn to_gpu(&mut self) -> Result<(), GpuOptimError>
renamed to move_to_gpu
Deprecated alias for Self::move_to_gpu.
Sourcepub fn to_cpu(&mut self) -> Result<(), GpuOptimError>
👎Deprecated since 0.3.2: renamed to move_to_cpu
pub fn to_cpu(&mut self) -> Result<(), GpuOptimError>
renamed to move_to_cpu
Deprecated alias for Self::move_to_cpu.
Sourcepub fn is_gpu_available(&self) -> bool
pub fn is_gpu_available(&self) -> bool
Whether a real device (not the CPU fallback) is backing this optimizer.
Sourcepub fn step_count(&self) -> u64
pub fn step_count(&self) -> u64
Number of updates applied so far.
Sourcepub fn next_effective_lr(&self) -> f32
pub fn next_effective_lr(&self) -> f32
Effective learning rate that the next step will use.