pub struct SparseAdamTable { /* private fields */ }Expand description
Sparse / lazy Adam optimizer over a 2-D embedding table.
Mirrors SparseAdam but operates on an Array2 with a CsrGradient.
Moment state is stored flat, indexed by row * cols + col.
Implementations
Sourceimpl SparseAdamTable
impl SparseAdamTable
Sourcepub fn new(config: SparseAdamConfig) -> Self
pub fn new(config: SparseAdamConfig) -> Self
Create a new table optimizer. State is allocated lazily on the first
SparseAdamTable::step.
Sourcepub fn global_step(&self) -> usize
pub fn global_step(&self) -> usize
The number of optimizer steps performed so far.
Sourcepub fn step(
&mut self,
params: &mut Array2<f64>,
grad: &CsrGradient,
) -> Result<(), GpuOptimError>
pub fn step( &mut self, params: &mut Array2<f64>, grad: &CsrGradient, ) -> Result<(), GpuOptimError>
Perform one sparse Adam update on the embedding table in place.
Errors
Returns GpuOptimError::DimensionMismatch on any shape disagreement and
propagates gradient validation errors.